@@ -8,11 +8,11 @@ import (
 	"github.com/olekukonko/tablewriter"
 	"github.com/pkg/errors"
 	"github.com/spf13/viper"
-	fly "github.com/superfly/fly-go"
 	"github.com/superfly/flyctl/agent"
 	"github.com/superfly/flyctl/flyctl"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flyutil"
 	"github.com/superfly/flyctl/internal/render"
 	"github.com/superfly/flyctl/internal/state"
 	"github.com/superfly/flyctl/internal/wireguard"
@@ -22,7 +22,7 @@ import (
 
 func runWireguardList(ctx context.Context) error {
 	io := iostreams.FromContext(ctx)
-	apiClient := fly.ClientFromContext(ctx)
+	apiClient := flyutil.ClientFromContext(ctx)
 
 	org, err := orgByArg(ctx)
 	if err != nil {
@@ -105,7 +105,7 @@ func runWireguardReset(ctx context.Context) error {
 		return err
 	}
 
-	apiClient := fly.ClientFromContext(ctx)
+	apiClient := flyutil.ClientFromContext(ctx)
 	agentclient, err := agent.Establish(ctx, apiClient)
 	if err != nil {
 		return err
@@ -122,7 +122,7 @@ func runWireguardReset(ctx context.Context) error {
 
 func runWireguardCreate(ctx context.Context) error {
 	io := iostreams.FromContext(ctx)
-	apiClient := fly.ClientFromContext(ctx)
+	apiClient := flyutil.ClientFromContext(ctx)
 
 	org, err := orgByArg(ctx)
 	if err != nil {
@@ -141,10 +141,10 @@ func runWireguardCreate(ctx context.Context) error {
 		name = args[2]
 	}
 
-	//TODO: allow custom network
+	// TODO: allow custom network
 	network := ""
 
-	state, err := wireguard.Create(apiClient, org, region, name, network)
+	state, err := wireguard.Create(apiClient, org, region, name, network, "static")
 	if err != nil {
 		return err
 	}
@@ -177,7 +177,7 @@ func runWireguardCreate(ctx context.Context) error {
 
 func runWireguardRemove(ctx context.Context) error {
 	io := iostreams.FromContext(ctx)
-	apiClient := fly.ClientFromContext(ctx)
+	apiClient := flyutil.ClientFromContext(ctx)
 
 	org, err := orgByArg(ctx)
 	if err != nil {
