@@ -560,6 +560,14 @@ func Depot() Bool {
 	}
 }
 
+func DepotScope() String {
+	return String{
+		Name:        "depot-scope",
+		Description: "The scope of the Depot builder's cache to use (org or app)",
+		Default:     "org",
+	}
+}
+
 func Nixpacks() Bool {
 	return Bool{
 		Name:        "nixpacks",
